pub struct FilesystemAdapter { /* private fields */ }Expand description
Filesystem source adapter.
Recursively walks a root directory, applying extension and glob filters during enumeration. Fetches file content and computes blake3 hashes.
Implementations
Sourceimpl FilesystemAdapter
impl FilesystemAdapter
Sourcepub fn from_spec(
source_name: &str,
spec: &SourceSpec,
) -> Result<Self, ResolveError>
pub fn from_spec( source_name: &str, spec: &SourceSpec, ) -> Result<Self, ResolveError>
Create a new FilesystemAdapter from a SourceSpec.
Errors
Returns ResolveError::UnknownAdapter if the spec is not a filesystem source.
Returns ResolveError::Io if a glob pattern is invalid.
Sourcepub fn from_fs_spec(
source_name: &str,
spec: &FilesystemSourceSpec,
) -> Result<Self, ResolveError>
pub fn from_fs_spec( source_name: &str, spec: &FilesystemSourceSpec, ) -> Result<Self, ResolveError>
Create a new FilesystemAdapter directly from a FilesystemSourceSpec.
Errors
Returns ResolveError::Io if a glob pattern is invalid.